@@ -20,7 +20,7 @@
 use serde::{Deserialize, Serialize};
 
 /// The properties of the register file.
-#[derive(Deserialize, Serialize)]
+#[derive(Default, Deserialize, Serialize)]
 pub struct RegisterFileConfig {
     /// If the register file supports renaming.
     renaming: bool,
